app/soc/logic/models/organization.py
changeset 1609 cd285bc524f1
parent 1512 97c4a718d6f4
child 1623 8b70d6bb3f8f
--- a/app/soc/logic/models/organization.py	Tue Mar 03 22:45:32 2009 +0000
+++ b/app/soc/logic/models/organization.py	Tue Mar 03 22:47:44 2009 +0000
@@ -27,12 +27,12 @@
 from soc.logic.models import group
 from soc.logic.models import org_app as org_app_logic
 from soc.logic.models import program as program_logic
+from soc.logic.models import rankerroot as ranker_root_logic
 from soc.logic.models import request as request_logic
 
 import soc.models.group
 import soc.models.organization
 
-
 class Logic(group.Logic):
   """Logic methods for the Organization model.
   """
@@ -52,9 +52,15 @@
 
 
   def _onCreate(self, entity):
     """Invites the group admin and backup admin.
     """
 
+    from soc.models import student_proposal
+
+    # create a new ranker
+    ranker_root_logic.logic.create(student_proposal.DEF_RANKER_NAME, entity,
+        student_proposal.DEF_SCORE, 100)
+
     fields = {
         'link_id': entity.link_id,
         'scope_path': entity.scope_path
@@ -52,9 +52,15 @@
 
   def _onCreate(self, entity):
-    """Invites the group admin and backup admin.
+    """Invites the group admin and backup admin and creates a rankerroot entity.
     """
 